@@ -294,32 +294,32 @@ sub decodeImdbKey($$$)
     if ( $title=~s/\s+\((\d\d\d\d)\)$//o ||
 	 $title=~s/\s+\((\d\d\d\d)\/[IVXL]+\)$//o ) {
 	# over-ride with what is given
-	if ( defined($year) ) {
-	    $hash{year}=$year;
+	if ( !defined($year) ) {
+	    $hash{year}=$1;
 	}
 	else {
-	    $hash{year}=$1;
+	    $hash{year}=$year;
 	}
     }
     elsif ( $title=~s/\s+\((\?\?\?\?)\)$//o ||
 	    $title=~s/\s+\((\?\?\?\?)\/[IVXL]+\)$//o ) {
 	# over-ride with what is given
-	if ( defined($year) ) {
-	    $hash{year}=$year;
+	if ( !defined($year) ) {
+	    $hash{year}=0;
 	}
 	else {
-	    $hash{year}="";
+	    $hash{year}=$year;
 	}
     }
     else {
 	$self->error("movie list format failed to decode year from title '$title'");
 	
 	# over-ride with what is given
-	if ( defined($year) ) {
-	    $hash{year}=$year;
+	if ( ! defined($year) ) {
+	    $hash{year}=0;
 	}
 	else {
-	    $hash{year}="";
+	    $hash{year}=$year;
 	}
     }
     $title=~s/(.*),\s*(The|A|Une|Las|Les|Los|L\'|Le|La|El|Das|De|Het|Een)$/$2 $1/og;
@@ -718,7 +718,7 @@ sub importActors($$$$)
 	    $cur_actorId++;
 
 	    my $c=$cur_name;
-	    $c=~s/\s*\([IVX]+\)//o;
+	    $c=~s/\s*\([IVXL]+\)//o;
 	    $tableInsert_sth1->execute($cur_actorId, $DB->makeSearchableTitle($c, 0), $cur_name);
 
 	    if ( $self->{showProgressBar} ) {
@@ -924,7 +924,7 @@ sub importDirectors($$$)
 		$found{$cur_name}=$directorCount;
 
 		my $c=$cur_name;
-		$c=~s/\s*\([IVX]+\)//o;
+		$c=~s/\s*\([IVXL]+\)//o;
 		$tableInsert_sth->execute($directorCount, $DB->makeSearchableTitle($c, 0), $cur_name);
 	    }
 
@@ -1450,6 +1450,7 @@ sub _prepStage
     if ( !$DB->connect() ) {
 	die "imdbdb connect failed:$DBI::errstr";
     }
+
     $DB->runSQL("PRAGMA synchronous = OFF");
     return($DB);
 
@@ -1779,6 +1780,26 @@ sub importAll($$)
     return($err);
 }
 
+=head2 optimize
+
+Optimize the database for better performance.
+
+=cut
+sub optimize($)
+{
+    my ($self)=@_;
+
+    my $DB=new IMDB::Local::DB(database=>"$self->{imdbDir}/imdb.db");
+    
+    if ( !$DB->connect() ) {
+	die "imdbdb connect failed:$DBI::errstr";
+    }
+
+    $DB->runSQL("VACUUM");
+    $DB->disconnect();
+    return(1);
+}
+
 sub _NOT_USED_checkSantity($)
 {
     my ($self)=@_;
