@@ -90,6 +90,10 @@ sub connect($)
 	#$c->dbh->{AutoCommit}=0;
     }
     if ( $c && $initIt==1 ) {
+	if ( $self->driver eq 'SQLite' ) {
+	    my $dbh=$self->dbh();
+	    $dbh->do("PRAGMA page_size = 8192");
+	}
 	$self->schema_init();
     }
     return($c);
@@ -126,82 +130,70 @@ sub create_table_indexes($$)
 {
     my ($self, $table)=@_;
 
-    if ( $table eq 'Titles' ) {
+    if ( !defined($table) || $table eq 'Titles' ) {
 	$self->runSQL("CREATE INDEX Titles_Idx1 on Titles (Year)");
 	$self->runSQL("CREATE INDEX Titles_Idx2 on Titles (SearchTitle)");
 	$self->runSQL("CREATE INDEX Titles_Idx3 on Titles (ParentID)");
-	return(1);
     }
-    elsif ( $table eq 'Directors') {
+    if ( !defined($table) || $table eq 'Directors') {
 	$self->runSQL("CREATE INDEX Directors_Idx1 on Directors (SearchName)");
-	return(1);
+	$self->runSQL("CREATE INDEX Directors_Idx2 on Titles2Directors (TitleID)");
     }
-    elsif ( $table eq 'Actors') {
+    if ( !defined($table) || $table eq 'Actors') {
 	$self->runSQL("CREATE INDEX Actors_Idx1 on Actors (SearchName)");
 	$self->runSQL("CREATE INDEX Actors_Idx2 on Actors (Name)");
 	$self->runSQL("CREATE INDEX Actors_Idx3 on Titles2Actors (TitleID)");
 	$self->runSQL("CREATE INDEX Actors_Idx4 on Titles2Hosts (TitleID)");
 	$self->runSQL("CREATE INDEX Actors_Idx5 on Titles2Narrators (TitleID)");
-	return(1);
     }
-    elsif ( $table eq 'Genres') {
+    if ( !defined($table) || $table eq 'Genres') {
 	$self->runSQL("CREATE INDEX Genres_Idx1 on Titles2Genres (TitleID)");
-	return(1);
     }
-    elsif ( $table eq 'Ratings') {
+    if ( !defined($table) || $table eq 'Ratings') {
 	$self->runSQL("CREATE INDEX Ratings_Idx1 on Ratings (TitleID)");
-	return(1);
     }
-    elsif ( $table eq 'Keywords') {
+    if ( !defined($table) || $table eq 'Keywords') {
 	$self->runSQL("CREATE INDEX Keywords_Idx1 on Titles2Keywords (TitleID)");
-	return(1);
     }
-    elsif ( $table eq 'Plots' ) {
+    if ( !defined($table) || $table eq 'Plots' ) {
 	$self->runSQL("CREATE INDEX Plots_Idx1 on Plots (TitleID)");
-	return(1);
     }
-    return(0);
+    return(1);
 }
 
 sub drop_table_indexes($$)
 {
     my ($self, $table)=@_;
 
-    if ( $table eq 'Titles' ) {
+    if ( !defined($table) || $table eq 'Titles' ) {
 	$self->runSQL("DROP INDEX IF EXISTS Titles_Idx1");
 	$self->runSQL("DROP INDEX IF EXISTS Titles_Idx2");
 	$self->runSQL("DROP INDEX IF EXISTS Titles_Idx3");
-	return(1);
     }
-    elsif ( $table eq 'Directors') {
+    if ( !defined($table) || $table eq 'Directors') {
 	$self->runSQL("DROP INDEX IF EXISTS Directors_Idx1");
-	return(1);
+	$self->runSQL("DROP INDEX IF EXISTS Directors_Idx2");
     }
-    elsif ( $table eq 'Actors') {
+    if ( !defined($table) || $table eq 'Actors') {
 	$self->runSQL("DROP INDEX IF EXISTS Actors_Idx1");
 	$self->runSQL("DROP INDEX IF EXISTS Actors_Idx2");
 	$self->runSQL("DROP INDEX IF EXISTS Actors_Idx3");
 	$self->runSQL("DROP INDEX IF EXISTS Actors_Idx4");
 	$self->runSQL("DROP INDEX IF EXISTS Actors_Idx5");
-	return(1);
     }
-    elsif ( $table eq 'Genres') {
+    if ( !defined($table) || $table eq 'Genres') {
 	$self->runSQL("DROP INDEX IF EXISTS Genres_Idx1");
-	return(1);
     }
-    elsif ( $table eq 'Ratings') {
+    if ( !defined($table) || $table eq 'Ratings') {
 	$self->runSQL("DROP INDEX IF EXISTS Ratings_Idx1");
-	return(1);
     }
-    elsif ( $table eq 'Keywords') {
+    if ( !defined($table) || $table eq 'Keywords') {
 	$self->runSQL("DROP INDEX IF EXISTS Keywords_Idx1");
-	return(1);
     }
-    elsif ( $table eq 'Plots' ) {
+    if ( !defined($table) || $table eq 'Plots' ) {
 	$self->runSQL("DROP INDEX IF EXISTS Plots_Idx1");
-	return(1);
     }
-    return(0);
+    return(1);
 }
 
 # Convert a title into a searchtitle by lowercasing,
