@@ -7,7 +7,7 @@ use Carp;
 
 =head1 NAME
 
-IMDB::Local::DB::Base - database abstraction with handy entry points
+IMDB::Local::DB::Base - Object to manage database abstraction with handy entry points.
 
 =head1 VERSION
 
@@ -15,7 +15,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '1.00';
 
 
 =head1 SYNOPSIS
@@ -897,6 +897,32 @@ sub table_exists($$)
     return(1);
 }
 
+=head2 table_exists
+
+Check to see if a given table exists. Uses table_list.
+
+=cut
+
+sub table_clear($$)
+{
+    my ($db, $table)=@_;
+
+    if ( !$db->isConnected() ) {
+	carp("not connected");
+    }
+    if ( $db->table_exists($table) ) {
+	if ( $db->runSQL("DELETE from $table") ) {
+	    if ( $db->driver eq 'SQLite' &&
+		 # reset state related to table (ie automatic id counters)
+		 $db->runSQL("DELETE from sqlite_sequence where name='$table'") ) {
+	    }
+	    $db->commit();
+	    return(1);
+	}
+    }
+    return(0);
+}
+
 =head2 column_info
 
 Retrieve information about a given column in a table. Changes to columns made after connect() may not be included.
