@@ -7,7 +7,7 @@ use Carp;
 
 =head1 NAME
 
-IMDB::Local::DB::RecordIterator - The great new IMDB::Local::DB::RecordIterator!
+IMDB::Local::DB::RecordIterator - Object to iterate through search results
 
 =head1 VERSION
 
@@ -15,7 +15,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '1.00';
 
 
 =head1 SYNOPSIS
