@@ -6,7 +6,7 @@ use warnings;
 
 =head1 NAME
 
-IMDB::Local::Rating - The great new IMDB::Local::Rating!
+IMDB::Local::Rating - Object representation of Rating information.
 
 =head1 VERSION
 
@@ -14,8 +14,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
-
+our $VERSION = '1.00';
 
 =head1 SYNOPSIS
 
@@ -39,14 +38,82 @@ if you don't export anything, such as for a purely object-oriented module.
 
 =cut
 
-sub function1 {
+use IMDB::Local::DB::BaseObject;
+use base qw(IMDB::Local::DB::BaseObject);
+
+use constant DB_TABLE => 'Ratings';
+use constant DB_KEY   => 'TitleID';
+
+use Class::MethodMaker
+    [ 
+      scalar => [DB_KEY],
+      array => [qw/ -static db_columns/],
+      new  => [qw/ -init -hash new/] ,
+    ];
+
+sub init($)
+{
+    my ($self)=@_;
+
+    # static array needs to be initialized only if it isn't already
+    #if ( !$self->db_ignoredColumns_count ) {
+    #$self->db_ignoredColumns_push(DB_COLUMNS_IGNORE);
+    #}
+
+    $self->initHandle(DB_TABLE, DB_KEY);
+
+    if ( $self->populateUsingKey($self->get(DB_KEY)) ) {
+	return $self;
+    }
+    return(undef);
 }
 
-=head2 function2
+use Carp;
 
-=cut
+sub createNew($%)
+{
+    my ($imdbdb, %args)=@_;
 
-sub function2 {
+    carp("no name given") if ( !defined($args{name}) );
+
+    my $id=$imdbdb->insert_db(DB_TABLE, DB_KEY, %args);
+    if ( !defined($id) ) {
+	return(undef);
+    }
+    return new IMDB::Local::Rating(imdbdb=>$imdbdb, TableID=>$id);
+}
+
+sub findByPlotID($$)
+{
+    my ($imdbdb, $id)=@_;
+    return new IMDB::Local::Rating(imdbdb=>$imdbdb, DB_KEY, $id);
+}
+
+sub findByName($$)
+{
+    my ($imdbdb, $name)=@_;
+
+    my $id=$imdbdb->select2Scalar("SELECT ".DB_KEY." from ".DB_TABLE." where name='$name'");
+    if ( defined($id) ) {
+	return new IMDB::Local::Rating(imdbdb=>$imdbdb, DB_KEY, $id);
+    }
+    return(undef);
+}
+
+sub getIDs($$)
+{
+    my ($class, $imdbdb)=@_;
+    my @ids;
+
+    my $res=$imdbdb->dbh->selectall_arrayref("SELECT ".DB_KEY." FROM ".DB_TABLE." ORDER BY ".DB_KEY."");
+    if ( !defined($res) ) {
+	return(@ids);
+    }
+
+    for my $list (@$res) {
+	push(@ids, $list->[0]);
+    }
+    return(@ids);
 }
 
 =head1 AUTHOR
